FTHttpOverrideConfig class

Properties

customHttpOverrides ↔ HttpOverrides?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isInTakeUrl ↔ bool Function(String url)?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
traceHeader ↔ bool
getter/setter pair
traceResource ↔ bool
getter/setter pair
webSocketCollectionEnabled → bool
no setter
webSocketResource ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

global → dynamic
no setter