FTLogger class
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
logConfig ({double ? sampleRate , bool ? enableLinkRumData , bool ? enableCustomLog , bool ? printCustomLogToConsole , FTLogCacheDiscard ? logCacheDiscard , int ? logCacheLimitCount , List <FTLogStatus > ? logLevelFilters , Map <String , String > ? globalContext })
→ Future <void >
Configure log output configuration
sampleRate Sampling rate
enableLinkRumData Whether to link with RUM
enableCustomLog Whether to enable custom logs
printCustomLogToConsole Whether to print custom logs to console
logCacheDiscard Log discard strategy
logLevelFilters Log level filters
globalContext Custom global parameters
logging (String content , FTLogStatus status , {Map <String , Object ? > ? property , bool ? isSilence })
→ Future <void >
Output log
content Log content
status Log status
property Additional property parameters (optional)
isSilence
loggingWithStatusString (String content , String status , {Map <String , Object ? > ? property })
→ Future <void >
Output log with a custom string status.
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited
ft_mobile_agent_flutter 0.5.7