FTRemoteConfigResult class

Constructors

FTRemoteConfigResult({required String triggerType, required bool success, required String platform, required int timestamp, String? rawJson, Object? errorCode, String? errorMessage, List<String>? appliedOverrideRuleIds})
FTRemoteConfigResult.fromMap(Map map)
factory

Properties

appliedOverrideRuleIds List<String>?
final
errorCode Object?
final
errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
platform String
final
rawJson String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final
timestamp int
final
triggerType String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited