FTTracer class

Constructors

FTTracer()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getTraceHeader(String url, {String? key}) Future<Map<String, String>>
Get trace http request header data key Unique id url Request address
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setConfig({double? sampleRate, TraceType? traceType, bool? enableLinkRUMData, bool? enableNativeAutoTrace, bool enableAutoTrace = false}) Future<void>
Configure trace sampleRate Sampling rate traceType Trace type enableLinkRUMData Whether to link with RUM data enableNativeAutoTrace Whether to enable native network automatic tracing iOS NSURLSession, Android OKhttp
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited