FTWebSocket class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
connect(
String url, {Iterable< String> ? protocols, Map<String, dynamic> ? headers, CompressionOptions compression = CompressionOptions.compressionDefault, HttpClient? customClient}) → Future<WebSocket> - Opens a WebSocket and, when WebSocket Resource collection is enabled, tracks only its opening handshake as a RUM Resource.